from ..._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class DetonationPoint:
    """A :py:class:`~abaqus.Material.Eos.DetonationPoint.DetonationPoint` object specifies a suboption of the Eos object. The DetonationPoint
    object defines either isotropic linear elastic shear or linear viscous shear behavior
    for a hydrodynamic material.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].eos.detonationPoint
            import odbMaterial
            session.odbs[name].materials[name].eos.detonationPoint

        The table data for this object are:
        
        - X value for coordinate of detonation point.
        - Y value for coordinate of detonation point.
        - Z value for coordinate of detonation point.
        - Detonation delay time.

        The corresponding analysis keywords are:

        - DETONATION POINT
    """

    @abaqus_method_doc
    def __init__(self, table: tuple):
        """This method creates a DetonationPoint object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].eos.DetonationPoint
                session.odbs[name].materials[name].eos.DetonationPoint

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        DetonationPoint
            A :py:class:`~abaqus.Material.Eos.DetonationPoint.DetonationPoint` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the DetonationPoint object."""
        ...



from .CombinedTestData import CombinedTestData
from ....Others.Mechanical.Viscosity.Trs import Trs
from ....TestData.ShearTestData import ShearTestData
from ....TestData.VolumetricTestData import VolumetricTestData
from .....UtilityAndView.abaqusConstants import *
from ....._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Viscoelastic:
    r"""The Viscoelastic object specifies dissipative behavior for use with elasticity.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].viscoelastic
            import odbMaterial
            session.odbs[name].materials[name].viscoelastic

        The table data for this object are:

        - If **frequency** = FORMULA, the table data for **table** specify the following:
        
            - Real part of :math:`g_{1}^{*}\left(g^{*}(\omega)=g_{1}^{*} f^{-a}\right)`
            - Imaginary part of :math:`g_{1}^{*}`.
            - Value of :math:`a`.
            - Real part of :math:`k_{1}^{*}\left(k^{*}(\omega)=k_{1}^{*} f^{-b}\right)`. If 
              the material is incompressible, this value is ignored.
            - Imaginary part of :math:`k_{1}^{*}`. If the material is incompressible, this 
              value is ignored.
            - Value of :math:`b`. If the material is incompressible, this value is ignored.
            
        - If **frequency** = TABULAR and **type** = ISOTROPIC and **preload** = NONE, or **time** = FREQUENCY_DATA 
          the table data for **table** specify the following:
          
            - Real part of :math:`\omega g^{*}\left(\omega \Re\left(g^{*}\right)=G_{\ell} / G_{\infty}\right)`.
            - Imaginary part of :math:`\omega g^{*}\left(\omega \mathfrak{J}\left(g^{*}\right)=1-G_{s} / G_{\infty}\right)`
            - Real part of :math:`\omega k^{*}\left(\omega \mathfrak{R}\left(k^{*}\right)=\mathrm{K}_{\ell} / \mathrm{K}_{\infty}\right)`. If the material is incompressible, this value is ignored.
            - Imaginary part of :math:`\omega k^{*}\left(\omega \mathfrak{I}\left(k^{*}\right)=1-\mathrm{K}_{s} / \mathrm{K}_{\infty}\right)`. If the material is incompressible, this value is ignored.
            - Frequency :math:`f` in cycles per time.
            
        - If **frequency** = TABULAR and **type** = ISOTROPIC and **preload** = UNIAXIAL the table data for **table** 
          specify the following:
        
            - Loss modulus.
            - Storage modulus.
            - Frequency.
            - Uniaxial strain.
            
        - If **frequency** = TABULAR and **type** = TRACTION and **preload** = NONE the table data for **table** 
          specify the following:
        
            - Normalized loss modulus.
            - Normalized shear modulus.
            - Frequency.
            
        - If **frequency** = TABULAR and **type** = TRACTION and **preload** = UNIAXIAL or 
          **preload** = UNIAXIAL_VOLUMETRIC the table data for **table** specify the following:
        
            - Loss modulus.
            - Storage modulus.
            - Frequency.
            - Closure.
            
        - If **time** = PRONY or **frequency** = PRONY, the table data for **table** specify the following:
        
            - :math:`\bar{g}_{1}^{P}`, the modulus ratio in the first term in the Prony series
              expansion of the shear relaxation modulus.
            - :math:`\bar{k}_{1}^{P}`, the modulus ratio in the first term in the Prony series 
              expansion of the bulk relaxation modulus.
            - :math:`\tau_{1}`, the relaxation time for the first term in the Prony series expansion.
            
        - If **frequency** = TABULAR and **type** = ISOTROPIC and **preload** = VOLUMETRIC or 
          **preload** = UNIAXIAL_VOLUMETRIC the table data for **volumetricTable** specify the following:
        
            - Loss modulus.
            - Storage modulus.
            - Frequency.
            - Volume ratio.

        The corresponding analysis keywords are:

        - VISCOELASTIC
    """

    #: A :py:class:`~abaqus.Material.Elastic.HyperElastic.ViscoElastic.CombinedTestData.CombinedTestData` object.
    combinedTestData: CombinedTestData = CombinedTestData(((),))

    #: A :py:class:`~abaqus.Material.TestData.ShearTestData.ShearTestData` object.
    shearTestData: ShearTestData = ShearTestData(((),))

    #: A :py:class:`~abaqus.Material.Others.Mechanical.Viscosity.Trs.Trs` object.
    trs: Trs = Trs()

    #: A :py:class:`~abaqus.Material.TestData.VolumetricTestData.VolumetricTestData` object.
    volumetricTestData: VolumetricTestData = VolumetricTestData(((),))

    @abaqus_method_doc
    def __init__(
        self,
        domain: SymbolicConstant,
        table: tuple,
        frequency: SymbolicConstant = FORMULA,
        type: SymbolicConstant = ISOTROPIC,
        preload: SymbolicConstant = NONE,
        time: SymbolicConstant = PRONY,
        errtol: float = 0,
        nmax: int = 13,
        volumetricTable: tuple = (),
    ):
        """This method creates a Viscoelastic object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].Viscoelastic
                session.odbs[name].materials[name].Viscoelastic

        Parameters
        ----------
        domain
            A SymbolicConstant specifying the domain definition. Possible values are:
            - FREQUENCY, specifying a frequency domain. This domain is only available for an Abaqus/Standard analysis.
            - TIME, specifying a time domain.
        table
            A sequence of sequences of Floats specifying the items described below.
        frequency
            A SymbolicConstant specifying the frequency domain definition. This argument is required
            only when **domain** = FREQUENCY. Possible values are FORMULA, TABULAR, PRONY,
            CREEP_TEST_DATA, and RELAXATION_TEST_DATA. The default value is FORMULA.
        type
            A SymbolicConstant specifying the type. This argument is required only when
            **domain** = FREQUENCY and **frequency** = TABULAR. Possible values are ISOTROPIC and TRACTION.
            The default value is ISOTROPIC.
        preload
            A SymbolicConstant specifying the preload. This argument is required only when
            **domain** = FREQUENCY and **frequency** = TABULAR. Possible values are NONE, UNIAXIAL,
            VOLUMETRIC, and UNIAXIAL_VOLUMETRIC. The default value is NONE.
        time
            A SymbolicConstant specifying the time domain definition. This argument is required only
            when **domain** = TIME. Possible values are PRONY, CREEP_TEST_DATA, RELAXATION_TEST_DATA,
            and FREQUENCY_DATA. The default value is PRONY.
        errtol
            A Float specifying the allowable average root-mean-square error of the data points in
            the least-squares fit. The Float values correspond to percentages; for example, 0.01 is
            1%. The default value is 0.01.This argument is valid only when **time** = CREEP_TEST_DATA,
            RELAXATION_TEST_DATA or FREQUENCY_DATA; or only when **frequency** = CREEP_TEST_DATA or
            RELAXATION_TEST_DATA.
        nmax
            An Int specifying the maximum number of terms NN in the Prony series. The maximum value
            is 13. The default value is 13.This argument is valid only when **time** = CREEP_TEST_DATA,
            RELAXATION_TEST_DATA or FREQUENCY_DATA; or only when **frequency** = CREEP_TEST_DATA or
            RELAXATION_TEST_DATA.
        volumetricTable
            A sequence of sequences of Floats specifying the items described below. The default
            value is an empty sequence.

        Returns
        -------
        Viscoelastic
            A :py:class:`~abaqus.Material.Elastic.HyperElastic.ViscoElastic.Viscoelastic.Viscoelastic` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the Viscoelastic object.

        Raises
        ------
        RangeError
        """
        ...



from .._decorators import abaqus_class_doc


@abaqus_class_doc
class OdbDataSurfaceSet:
    """The OdbDataSurfaceSet object stores surface set data.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import visualization
            session.odbData[name].surfaceSets[i]
    """

    #: A String specifying the set name. This attribute is read-only.
    name: str = ""

    #: A String-to-tuple-of-Ints Dictionary specifying the elements in the set. This attribute
    #: is read-only.
    elements: str = ""

    #: A String-to-tuple-of-Ints Dictionary specifying the facets corresponding to the
    #: **elements**. This attribute is read-only.
    facets: str = ""



from .PredefinedField import PredefinedField
from ..Assembly.PartInstanceArray import PartInstanceArray
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class MaterialAssignment(PredefinedField):
    """The MaterialAssignment object stores the data for an initial material assignment
    predefined field, for use with an Eulerian analysis.
    The MaterialAssignment object is derived from the PredefinedField object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].predefinedFields[name]

        The corresponding analysis keywords are:

        - INITIAL CONDITIONS
    """

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the predefined field is applied.
    region: Region = Region()

    #: A String specifying the repository key.
    name: str

    #: A :py:class:`~abaqus.Assembly.PartInstanceArray.PartInstanceArray` object specifying the part instances to which the predefined field
    #: is applied. All instances must be assigned the same Eulerian section.
    instanceList: PartInstanceArray

    #: A Boolean specifying whether the volume fraction data will be uniform or defined by
    #: discrete fields. The default value is OFF.
    useFields: Boolean = OFF

    #: A sequence of tuples specifying the uniform volume fractions to be assigned. This
    #: argument is valid only when **useFields** = FALSE. Each tuple contains two entries:A Region
    #: object.A tuple of Floats specifying the uniform volume fraction values. The length of
    #: the tuple must match the number of material instance names specified in the Eulerain
    #: section assigned to part instances specified by **instanceList**.
    assignmentList: tuple = ()

    #: A sequence of tuples specifying the discrete volume fractions to be assigned. This
    #: argument is valid only when **useFields** = TRUE. Each tuple contains two entries:A Region
    #: object.A tuple of Strings specifying Discrete Field names. The length of the tuple must
    #: match the number of material instance names specified in the Eulerain section assigned
    #: to part instances specified by **instanceList**.
    fieldList: tuple = ()

    #: A sequence of three Ints specifying colors used to display the material instance
    #: assignments. This is a sequence of R,G,B colors, where the values are represented by
    #: integers between 0 and 255. The default value is an empty sequence.
    colorList: tuple = ()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        instanceList: PartInstanceArray,
        useFields: Boolean = OFF,
        assignmentList: tuple = (),
        fieldList: tuple = (),
        colorList: tuple = (),
    ):
        """This method creates a MaterialAssignment predefined field object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].MaterialAssignment

        Parameters
        ----------
        name
            A String specifying the repository key.
        instanceList
            A :py:class:`~abaqus.Assembly.PartInstanceArray.PartInstanceArray` object specifying the part instances to which the predefined field
            is applied. All instances must be assigned the same Eulerian section.
        useFields
            A Boolean specifying whether the volume fraction data will be uniform or defined by
            discrete fields. The default value is OFF.
        assignmentList
            A sequence of tuples specifying the uniform volume fractions to be assigned. This
            argument is valid only when **useFields** = FALSE. Each tuple contains two entries:A Region
            object.A tuple of Floats specifying the uniform volume fraction values. The length of
            the tuple must match the number of material instance names specified in the Eulerain
            section assigned to part instances specified by **instanceList**.
        fieldList
            A sequence of tuples specifying the discrete volume fractions to be assigned. This
            argument is valid only when **useFields** = TRUE. Each tuple contains two entries:A Region
            object.A tuple of Strings specifying Discrete Field names. The length of the tuple must
            match the number of material instance names specified in the Eulerain section assigned
            to part instances specified by **instanceList**.
        colorList
            A sequence of three Ints specifying colors used to display the material instance
            assignments. This is a sequence of R,G,B colors, where the values are represented by
            integers between 0 and 255. The default value is an empty sequence.

        Returns
        -------
        MaterialAssignment
            A :py:class:`~abaqus.PredefinedField.MaterialAssignment.MaterialAssignment` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        useFields: Boolean = OFF,
        assignmentList: tuple = (),
        fieldList: tuple = (),
        colorList: tuple = (),
    ):
        """This method modifies the MaterialAssignment object.

        Parameters
        ----------
        useFields
            A Boolean specifying whether the volume fraction data will be uniform or defined by
            discrete fields. The default value is OFF.
        assignmentList
            A sequence of tuples specifying the uniform volume fractions to be assigned. This
            argument is valid only when **useFields** = FALSE. Each tuple contains two entries:A Region
            object.A tuple of Floats specifying the uniform volume fraction values. The length of
            the tuple must match the number of material instance names specified in the Eulerain
            section assigned to part instances specified by **instanceList**.
        fieldList
            A sequence of tuples specifying the discrete volume fractions to be assigned. This
            argument is valid only when **useFields** = TRUE. Each tuple contains two entries:A Region
            object.A tuple of Strings specifying Discrete Field names. The length of the tuple must
            match the number of material instance names specified in the Eulerain section assigned
            to part instances specified by **instanceList**.
        colorList
            A sequence of three Ints specifying colors used to display the material instance
            assignments. This is a sequence of R,G,B colors, where the values are represented by
            integers between 0 and 255. The default value is an empty sequence.
        """
        ...



from .RayleighDampingComponentArray import RayleighDampingComponentArray
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class RayleighDamping:
    """A :py:class:`~abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping` object contains Rayleigh Damping parameters.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import step
            mdb.models[name].steps[name].rayleighDamping
    """

    #: A :py:class:`~abaqus.StepMiscellaneous.RayleighDampingComponentArray.RayleighDampingComponentArray` object.
    components: RayleighDampingComponentArray = []



import typing

from .XYData import XYData
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_function_doc

"""This method writes an XYData object to a user-defined ASCII file. 

"""


@abaqus_function_doc
def writeXYReport(fileName: str, xyData: typing.Tuple[XYData, ...], appendMode: Boolean = ON):
    """This method writes an XYData object to a user-defined ASCII file.

    .. note:: 
        This function can be accessed by:

        .. code-block:: python

            session.writeXYReport

    Parameters
    ----------
    fileName
        A String specifying the name of the file to which **X - Y** data will be written.
    xyData
        A sequence of XYData objects to be written to the output file.
    appendMode
        A Boolean specifying whether to append the **X - Y** data to the existing file. The default
        value is ON.
    """
    ...



from .....UtilityAndView.abaqusConstants import *
from ....._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class CastIronTensionHardening:
    r"""The CastIronTensionHardening object specifies hardening for the Cast- Iron plasticity
    model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].castIronPlasticity.castIronTensionHardening
            import odbMaterial
            session.odbs[name].materials[name].castIronPlasticity.castIronTensionHardening

        The table data for this object are:

        - Yield stress in uniaxial tension, :math:`\sigma_t`.
        - The absolute value of the corresponding Plastic strain.(The first tabular value entered must always be zero.)
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - CAST IRON TENSION HARDENING
    """

    @abaqus_method_doc
    def __init__(
        self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0
    ):
        """This method creates a CastIronTensionHardening object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].castIronPlasticity.CastIronTensionHardening.CastIronTensionHardeningrials[name].castIronPlasticity.CastIronTensionHardening
            
        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below. 
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF. 
        dependencies
            An Int specifying the number of field variable dependencies. The default value is 0. 

        Returns
        -------
        CastIronTensionHardening
            A :py:class:`~abaqus.Material.Plastic.Metal.CastIron.CastIronTensionHardening.CastIronTensionHardening` object. 

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the CastIronTensionHardening object.

        Raises
        ------
        RangeError
        """
        ...



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class PropertyTableData:
    """A PropertyTableData is an object that is used to specify the property table of the
    respective property table type.
    The values in each column in the PropertyTableData object corresponds to the properties
    and variables mentioned in the PropertyTable object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            mdb.models[name].tableCollections[name].propertyTables[name].propertyTableDatas[name]

        The corresponding analysis keywords are:

        - PROPERTY TABLE TYPE
        - PROPERTY TABLE

    .. versionadded:: 2020
        The `PropertyTableData` class was added.
    """

    #: A String specifying a unique label name for the current PropertyTable object.
    label: str = ""

    #: A SymbolicConstant specifying the type of regularize to the user-defined property data.
    regularize: SymbolicConstant = None

    #: A SymbolicConstant specifying the type of extrapolation of dependent variables outside
    #: the specified range of the independent variables.
    extrapolate: SymbolicConstant = None

    #: A Boolean specifying the dependency of properties on temperature.
    isTemp: Boolean = OFF

    #: An Int specifying the field variables on which properties are dependent.
    fieldNums: int = None

    #: A Double specifying the tolerance to be used to regularize the property table data.
    regularizeTolerance: str = ""

    #: An Array of doubles specifying the values of the properties, the variables mentioned in
    #: PropertyTable, and the field variables mentioned in PropertyTableData.
    data: str = ""

    @abaqus_method_doc
    def __init__(
        self,
        label: str = "",
        regularize: SymbolicConstant = None,
        extrapolate: SymbolicConstant = None,
        isTemp: Boolean = OFF,
        fieldNums: int = None,
        regularizeTolerance: str = "",
        data: str = "",
    ):
        """This method creates a PropertyTableData object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].tableCollections[name].propertyTables[name].PropertTableData

        Parameters
        ----------
        label
            A String specifying a unique label name for the current PropertyTable object.
        regularize
            A SymbolicConstant specifying the type of regularize to the user-defined property data.
        extrapolate
            A SymbolicConstant specifying the type of extrapolation of dependent variables outside
            the specified range of the independent variables.
        isTemp
            A Boolean specifying the dependency of properties on temperature.
        fieldNums
            An Int specifying the field variables on which properties are dependent.
        regularizeTolerance
            A Double specifying the tolerance to be used to regularize the property table data.
        data
            An Array of doubles specifying the values of the properties, the variables mentioned in
            PropertyTable, and the field variables mentioned in PropertyTableData.

        Returns
        -------
        PropertyTableData
            A :py:class:`~abaqus.TableCollection.PropertyTableData.PropertyTableData` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the PropertyTableData object.

        Returns
        -------

        Raises
        ------
        RangeError
        """
        ...



from ..._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class DamageStabilization:
    """The DamageStabilization object specifies the viscosity coefficients for the damage model
    for fiber-reinforced materials.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].ductileDamageInitiation.damageStabilization
            mdb.models[name].materials[name].fldDamageInitiation.damageStabilization
            mdb.models[name].materials[name].flsdDamageInitiation.damageStabilization
            mdb.models[name].materials[name].hashinDamageInitiation.damageStabilization
            mdb.models[name].materials[name].johnsonCookDamageInitiation.damageStabilization
            mdb.models[name].materials[name].maxeDamageInitiation.damageStabilization
            mdb.models[name].materials[name].maxpeDamageInitiation.damageStabilization
            mdb.models[name].materials[name].maxpsDamageInitiation.damageStabilization
            mdb.models[name].materials[name].maxsDamageInitiation.damageStabilization
            mdb.models[name].materials[name].mkDamageInitiation.damageStabilization
            mdb.models[name].materials[name].msfldDamageInitiation.damageStabilization
            mdb.models[name].materials[name].quadeDamageInitiation.damageStabilization
            mdb.models[name].materials[name].quadsDamageInitiation.damageStabilization
            mdb.models[name].materials[name].shearDamageInitiation.damageStabilization
            import odbMaterial
            session.odbs[name].materials[name].ductileDamageInitiation.damageStabilization
            session.odbs[name].materials[name].fldDamageInitiation.damageStabilization
            session.odbs[name].materials[name].flsdDamageInitiation.damageStabilization
            session.odbs[name].materials[name].hashinDamageInitiation.damageStabilization
            session.odbs[name].materials[name].johnsonCookDamageInitiation.damageStabilization
            session.odbs[name].materials[name].maxeDamageInitiation.damageStabilization
            session.odbs[name].materials[name].maxpeDamageInitiation.damageStabilization
            session.odbs[name].materials[name].maxpsDamageInitiation.damageStabilization
            session.odbs[name].materials[name].maxsDamageInitiation.damageStabilization
            session.odbs[name].materials[name].mkDamageInitiation.damageStabilization
            session.odbs[name].materials[name].msfldDamageInitiation.damageStabilization
            session.odbs[name].materials[name].quadeDamageInitiation.damageStabilization
            session.odbs[name].materials[name].quadsDamageInitiation.damageStabilization
            session.odbs[name].materials[name].shearDamageInitiation.damageStabilization

        The corresponding analysis keywords are:

        - DAMAGE STABILIZATION
    """

    @abaqus_method_doc
    def __init__(
        self,
        fiberTensileCoeff: float,
        fiberCompressiveCoeff: float,
        matrixTensileCoeff: float,
        matrixCompressiveCoeff: float,
    ):
        """This method creates a DamageStabilization object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].ductileDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].fldDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].flsdDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].hashinDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].johnsonCookDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].maxeDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].maxpeDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].maxpsDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].maxsDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].mkDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].msfldDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].quadeDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].quadsDamageInitiation.DamageStabilization
                mdb.models[name].materials[name].shearDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].ductileDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].fldDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].flsdDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].hashinDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].johnsonCookDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].maxeDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].maxpeDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].maxpsDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].maxsDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].mkDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].msfldDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].quadeDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].quadsDamageInitiation.DamageStabilization
                session.odbs[name].materials[name].shearDamageInitiation.DamageStabilization
            
        Parameters
        ----------
        fiberTensileCoeff
            A Float specifying the viscosity coefficient for the fiber tensile failure mode. 
        fiberCompressiveCoeff
            A Float specifying the viscosity coefficient for the fiber compressive failure mode. 
        matrixTensileCoeff
            A Float specifying the viscosity coefficient for the matrix tensile failure mode. 
        matrixCompressiveCoeff
            A Float specifying the viscosity coefficient for the matrix compressive failure mode. 

        Returns
        -------
        DamageStabilization
            A :py:class:`~abaqus.Material.ProgressiveDamageFailure.DamageStabilization.DamageStabilization` object. 

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the DamageStabilization object.

        Raises
        ------
        RangeError
        """
        ...



import typing

from .ConstrainedSketchGeometry import ConstrainedSketchGeometry
from ...UtilityAndView.abaqusConstants import *
from ..._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class getPointAtDistance(ConstrainedSketchGeometry):
    
    @abaqus_method_doc
    def __init__(self, point: typing.Tuple[float, ...], distance: str, percentage: Boolean = OFF):
        """This method returns a point offset along the given ConstrainedSketchGeometry from the
        given end by a specified arc length distance or a percentage of the total length of the
        ConstrainedSketchGeometry object.

        Parameters
        ----------
        point
            A pair of Floats specifying the point from which the distance is to be measured.
        distance
            A float specifying the arc length distance along the ConstrainedSketchGeometry from the
            **point** at which the required point is situated.
        percentage
            A Boolean that specifies if the **distance** is an absolute distance or is a fraction
            relative to the length of the ConstrainedSketchGeometry object.

        Returns
        -------
        typing.Tuple[float, ...]
            A pair of floats representing the point along the edge.

        """
        ...



from ...._decorators import abaqus_class_doc, abaqus_method_doc

@abaqus_class_doc
class SuperElasticHardening:
    """The SuperElasticHardening object specifies the dependence of the yield stress on the
    total strain to define the piecewise linear hardening of a martensite material model.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import material
            mdb.models[name].materials[name].superElasticity.SuperElasticHardening
            import odbMaterial
            session.odbs[name].materials[name].superElasticity.SuperElasticHardening

        The table data for this object are:

        - Yield Stress.
        - Total Strain.

        The corresponding analysis keywords are:

        - SUPERELASTIC HARDENING
    """

    @abaqus_method_doc
    def __init__(self, table: tuple):
        """This method creates a SuperElasticHardening object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].materials[name].superElasticity.SuperElasticHardening
                session.odbs[name].materials[name].superElasticity.SuperElasticHardening

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.

        Returns
        -------
        SuperElasticHardening
            A :py:class:`~abaqus.Material.Plastic.SuperElastic.SuperElasticHardening.SuperElasticHardening` object.

        Raises
        ------
        RangeError
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the SuperElasticHardening object.

        Raises
        ------
        RangeError
        """
        ...



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ElemType:
    """The ElemType object is an argument object used as an argument in the setElementType
    command.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import mesh
    """

    #: A SymbolicConstant specifying the Abaqus element code or just the element shape.
    #: Possible values are:
    #: 
    #: - C3D8R, specifying a 8-node linear brick, reduced integration with hourglass control.
    #: - CODE, specifying add more codes.
    #: - UNKNOWN_TRI, specifying an unknown element type associated with a triangular shape.
    #: - UNKNOWN_QUAD, specifying an unknown element type associated with a quadrilateral
    #:   shape.
    #: - UNKNOWN_HEX, specifying an unknown element type associated with a hexahedral shape.
    #: - UNKNOWN_WEDGE, specifying an unknown element type associated with a wedge shape.
    #: - UNKNOWN_TET, specifying an unknown element type associated with a tetrahedral shape.
    elemCode: SymbolicConstant

    #: A SymbolicConstant specifying the Abaqus element library to use. Possible values are
    #: STANDARD and EXPLICIT. The default value is STANDARD.
    elemLibrary: SymbolicConstant = STANDARD

    #: A Float specifying the hourglass stiffness. (For shell elements this is the membrane
    #: hourglass stiffness.) A value of zero indicates the default value should be used. The
    #: default value will be used where appropriate. The default value is 0.0.This argument is
    #: applicable only to some Abaqus/Standard elements.
    hourglassStiffness: float = 0

    #: A Float specifying the bending hourglass stiffness. A value of zero indicates the
    #: default value should be used. The default value will be used where appropriate. The
    #: default value is 0.0.This argument is applicable only to some Abaqus/Standard elements.
    bendingHourglass: float = 0

    #: A Float specifying the drilling hourglass scaling factor. A value of zero indicates the
    #: default value should be used. The default value will be used where appropriate. The
    #: default value is 0.0.This argument is applicable only to some Abaqus/Standard elements.
    drillingHourglass: float = 0

    #: A SymbolicConstant specifying the kinematic split control. Possible values are
    #: AVERAGE_STRAIN, ORTHOGONAL, and CENTROID. The default value is AVERAGE_STRAIN.This
    #: argument is applicable only to some Abaqus/Explicit elements.
    kinematicSplit: SymbolicConstant = AVERAGE_STRAIN

    #: A Boolean specifying whether to prevent negative element volumes or other excessive
    #: distortions in crushable materials. The default value is OFF.This argument is applicable
    #: only to some Abaqus/Explicit elements.
    distortionControl: Boolean = OFF

    #: A Float specifying the length ratio for distortion control in crushable materials.
    #: Possible values are 0.0 ≤≤ **lengthRatio** ≤≤ 1.0. The default value is
    #: **lengthRatio** = 0.10.1This argument is applicable only when **distortionControl** is ON.
    lengthRatio: float = ON

    #: A Boolean specifying the second-order accuracy option. The default value is OFF.This
    #: argument is applicable only to some Abaqus/Explicit elements.
    secondOrderAccuracy: Boolean = OFF

    #: A SymbolicConstant specifying the hourglass control. Possible values are
    #: RELAX_STIFFNESS, STIFFNESS, VISCOUS, ENHANCED, and COMBINED. The default value is
    #: ENHANCED.This argument is applicable only to some Abaqus/Explicit elements.
    hourglassControl: SymbolicConstant = ENHANCED

    #: A Float specifying a weight factor when **hourglassControl** = COMBINED. The default value
    #: is 0.5.This argument is applicable only to some Abaqus/Explicit elements.
    weightFactor: float = 0

    #: A Float specifying the displacement hourglass scaling factor. The default value will be
    #: used where appropriate. The default value is 1.0.This argument is applicable only to
    #: some Abaqus/Explicit elements.
    displacementHourglass: float = 1

    #: A Float specifying the rotational hourglass scaling factor. The default value will be
    #: used where appropriate. The default value is 1.0.This argument is applicable only to
    #: some Abaqus/Explicit elements.
    rotationalHourglass: float = 1

    #: A Float specifying the out-of-plane displacement hourglass scaling factor. The default
    #: value will be used where appropriate. The default value is 1.0.This argument is
    #: applicable only to some Abaqus/Explicit elements.
    outOfPlaneDisplacementHourglass: float = 1

    #: A SymbolicConstant specifying the element deletion option. Possible values are DEFAULT,
    #: ON, and OFF. The default value is DEFAULT.
    elemDeletion: SymbolicConstant = DEFAULT

    #: A SymbolicConstant specifying the particle conversion option for smoothed particle
    #: hydrodynamics. When not OFF or DEFAULT this argument refers to the criterion used for
    #: conversion of elements to particles. Possible values are DEFAULT, OFF, TIME, STRAIN, and
    #: STRESS. The default value is DEFAULT.This argument is applicable only to some
    #: Abaqus/Explicit elements.
    particleConversion: SymbolicConstant = DEFAULT

    #: A Float specifying the threshold value for the particle conversion criterion specified
    #: by **particleConversion**. The default value is 0.0.This argument is applicable only to
    #: some Abaqus/Explicit elements.
    particleConversionThreshold: float = 0

    #: An Int specifying the number of particles per direction for element conversion when
    #: **particleConversion** is specified. The default value is 1.This argument is applicable
    #: only to some Abaqus/Explicit elements.
    particleConversionPPD: int = 1

    #: A SymbolicConstant specifying the interpolation function for particle conversion when
    #: **particleConversion** is specified. Possible values are CUBIC, QUADRATIC, and QUINTIC.
    #: The default value is CUBIC.This argument is applicable only to some Abaqus/Explicit
    #: elements.
    particleConversionKernel: SymbolicConstant = CUBIC

    #: A Float specifying the maximum degradation option for damage control. The default value
    #: is −1.0.
    maxDegradation: float = None

    #: A Float specifying the viscosity option. The default value is 0.0.This argument is
    #: applicable only to some Abaqus/Standard elements.
    viscosity: float = 0

    #: A Float specifying the linear bulk viscosity scaling factor option for Abaqus/Explicit.
    #: The default value is 1.0.
    linearBulkViscosity: float = 1

    #: A Float specifying the quadratic bulk viscosity scaling factor option for
    #: Abaqus/Explicit. The default value is 1.0.
    quadraticBulkViscosity: float = 1

    #: An Int specifying the number of Fourier modes. Possible values are 1, 2, 3, and 4. The
    #: default value is 1.This argument is applicable only for axisymmetric elements with
    #: nonlinear asymmetric deformation.
    #:
    #: .. versionadded:: 2019
    #:     The `numFourierModes` attribute was added.
    numFourierModes: int = 1

    #: An Int specifying the positive offset number for specifying the additional nodes needed
    #: in the connectivity.This argument is applicable only for axisymmetric elements with
    #: nonlinear asymmetric deformation.
    #:
    #: .. versionadded:: 2019
    #:     The `nodeOffset` attribute was added.
    nodeOffset: int = None

    @abaqus_method_doc
    def __init__(
        self,
        elemCode: SymbolicConstant,
        elemLibrary: SymbolicConstant = STANDARD,
        hourglassStiffness: float = 0,
        bendingHourglass: float = 0,
        drillingHourglass: float = 0,
        kinematicSplit: SymbolicConstant = AVERAGE_STRAIN,
        distortionControl: Boolean = OFF,
        lengthRatio: float = ON,
        secondOrderAccuracy: Boolean = OFF,
        hourglassControl: SymbolicConstant = ENHANCED,
        weightFactor: float = 0,
        displacementHourglass: float = 1,
        rotationalHourglass: float = 1,
        outOfPlaneDisplacementHourglass: float = 1,
        elemDeletion: SymbolicConstant = DEFAULT,
        particleConversion: SymbolicConstant = DEFAULT,
        particleConversionThreshold: float = 0,
        particleConversionPPD: int = 1,
        particleConversionKernel: SymbolicConstant = CUBIC,
        maxDegradation: float = None,
        viscosity: float = 0,
        linearBulkViscosity: float = 1,
        quadraticBulkViscosity: float = 1,
        numFourierModes: int = 1,
        nodeOffset: int = None,
    ):
        """This method creates an ElemType object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mesh.ElemType

        Parameters
        ----------
        elemCode
            A SymbolicConstant specifying the Abaqus element code or just the element shape.
            Possible values are:

            - C3D8R, specifying a 8-node linear brick, reduced integration with hourglass control.
            - CODE, specifying add more codes.
            - UNKNOWN_TRI, specifying an unknown element type associated with a triangular shape.
            - UNKNOWN_QUAD, specifying an unknown element type associated with a quadrilateral
              shape.
            - UNKNOWN_HEX, specifying an unknown element type associated with a hexahedral shape.
            - UNKNOWN_WEDGE, specifying an unknown element type associated with a wedge shape.
            - UNKNOWN_TET, specifying an unknown element type associated with a tetrahedral shape.
        elemLibrary
            A SymbolicConstant specifying the Abaqus element library to use. Possible values are
            STANDARD and EXPLICIT. The default value is STANDARD.
        hourglassStiffness
            A Float specifying the hourglass stiffness. (For shell elements this is the membrane
            hourglass stiffness.) A value of zero indicates the default value should be used. The
            default value will be used where appropriate. The default value is 0.0.This argument is
            applicable only to some Abaqus/Standard elements.
        bendingHourglass
            A Float specifying the bending hourglass stiffness. A value of zero indicates the
            default value should be used. The default value will be used where appropriate. The
            default value is 0.0.This argument is applicable only to some Abaqus/Standard elements.
        drillingHourglass
            A Float specifying the drilling hourglass scaling factor. A value of zero indicates the
            default value should be used. The default value will be used where appropriate. The
            default value is 0.0.This argument is applicable only to some Abaqus/Standard elements.
        kinematicSplit
            A SymbolicConstant specifying the kinematic split control. Possible values are
            AVERAGE_STRAIN, ORTHOGONAL, and CENTROID. The default value is AVERAGE_STRAIN.This
            argument is applicable only to some Abaqus/Explicit elements.
        distortionControl
            A Boolean specifying whether to prevent negative element volumes or other excessive
            distortions in crushable materials. The default value is OFF.This argument is applicable
            only to some Abaqus/Explicit elements.
        lengthRatio
            A Float specifying the length ratio for distortion control in crushable materials.
            Possible values are 0.0 ≤≤ **lengthRatio** ≤≤ 1.0. The default value is
            **lengthRatio** = 0.10.1This argument is applicable only when **distortionControl** is ON.
        secondOrderAccuracy
            A Boolean specifying the second-order accuracy option. The default value is OFF.This
            argument is applicable only to some Abaqus/Explicit elements.
        hourglassControl
            A SymbolicConstant specifying the hourglass control. Possible values are
            RELAX_STIFFNESS, STIFFNESS, VISCOUS, ENHANCED, and COMBINED. The default value is
            ENHANCED.This argument is applicable only to some Abaqus/Explicit elements.
        weightFactor
            A Float specifying a weight factor when **hourglassControl** = COMBINED. The default value
            is 0.5.This argument is applicable only to some Abaqus/Explicit elements.
        displacementHourglass
            A Float specifying the displacement hourglass scaling factor. The default value will be
            used where appropriate. The default value is 1.0.This argument is applicable only to
            some Abaqus/Explicit elements.
        rotationalHourglass
            A Float specifying the rotational hourglass scaling factor. The default value will be
            used where appropriate. The default value is 1.0.This argument is applicable only to
            some Abaqus/Explicit elements.
        outOfPlaneDisplacementHourglass
            A Float specifying the out-of-plane displacement hourglass scaling factor. The default
            value will be used where appropriate. The default value is 1.0.This argument is
            applicable only to some Abaqus/Explicit elements.
        elemDeletion
            A SymbolicConstant specifying the element deletion option. Possible values are DEFAULT,
            ON, and OFF. The default value is DEFAULT.
        particleConversion
            A SymbolicConstant specifying the particle conversion option for smoothed particle
            hydrodynamics. When not OFF or DEFAULT this argument refers to the criterion used for
            conversion of elements to particles. Possible values are DEFAULT, OFF, TIME, STRAIN, and
            STRESS. The default value is DEFAULT.This argument is applicable only to some
            Abaqus/Explicit elements.
        particleConversionThreshold
            A Float specifying the threshold value for the particle conversion criterion specified
            by **particleConversion**. The default value is 0.0.This argument is applicable only to
            some Abaqus/Explicit elements.
        particleConversionPPD
            An Int specifying the number of particles per direction for element conversion when
            **particleConversion** is specified. The default value is 1.This argument is applicable
            only to some Abaqus/Explicit elements.
        particleConversionKernel
            A SymbolicConstant specifying the interpolation function for particle conversion when
            **particleConversion** is specified. Possible values are CUBIC, QUADRATIC, and QUINTIC.
            The default value is CUBIC.This argument is applicable only to some Abaqus/Explicit
            elements.
        maxDegradation
            A Float specifying the maximum degradation option for damage control. The default value
            is −1.0.
        viscosity
            A Float specifying the viscosity option. The default value is 0.0.This argument is
            applicable only to some Abaqus/Standard elements.
        linearBulkViscosity
            A Float specifying the linear bulk viscosity scaling factor option for Abaqus/Explicit.
            The default value is 1.0.
        quadraticBulkViscosity
            A Float specifying the quadratic bulk viscosity scaling factor option for
            Abaqus/Explicit. The default value is 1.0.
        numFourierModes
            An Int specifying the number of Fourier modes. Possible values are 1, 2, 3, and 4. The
            default value is 1.This argument is applicable only for axisymmetric elements with
            nonlinear asymmetric deformation.

            .. versionadded:: 2019
                The `numFourierModes` argument was added.
        nodeOffset
            An Int specifying the positive offset number for specifying the additional nodes needed
            in the connectivity.This argument is applicable only for axisymmetric elements with
            nonlinear asymmetric deformation.

            .. versionadded:: 2019
                The `nodeOffset` argument was added.

        Returns
        -------
        elemType: ElemType
            An :py:class:`~abaqus.Mesh.ElemType.ElemType` object
        """
        ...



from .ConnectorBehaviorOption import ConnectorBehaviorOption
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ConnectorLock(ConnectorBehaviorOption):
    """The ConnectorLock object defines locking criteria for one or more available components
    of a connector's relative motion.
    The ConnectorLock object is derived from the ConnectorBehaviorOption object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import section
            mdb.models[name].sections[name].behaviorOptions[i]
            import odbSection
            session.odbs[name].sections[name].behaviorOptions[i]

        The corresponding analysis keywords are:

        - CONNECTOR LOCK
    """

    #: The SymbolicConstant ALL or an Int specifying the motion components that are locked. If
    #: an Int is specified, only that motion component is locked when the locking criteria are
    #: satisfied. If **lockingComponent** = ALL, all motion components are locked. The default
    #: value is ALL.
    lockingComponent: SymbolicConstant = ALL

    #: None or a Float specifying the lower bound for the connector's relative position for all
    #: specified components, or no lower bound. The default value is None.
    minMotion: float = None

    #: None or a Float specifying the upper bound for the connector's relative position for all
    #: specified components, or no upper bound. The default value is None.
    maxMotion: float = None

    #: None or a Float specifying the lower bound of the force or moment in the directions of
    #: the specified components at which locking occurs, or no lower bound. The default value
    #: is None.
    minForce: float = None

    #: None or a Float specifying the upper bound of the force or moment in the directions of
    #: the specified components at which locking occurs, or no upper bound. The default value
    #: is None.
    maxForce: float = None

    #: A sequence of Ints specifying the components of relative motion for which the behavior
    #: is defined. Possible values are 1 ≤≤ **components** ≤≤ 6. Only available components can be
    #: specified. The default value is an empty sequence.
    components: tuple = ()

    @abaqus_method_doc
    def __init__(
        self,
        lockingComponent: SymbolicConstant = ALL,
        minMotion: float = None,
        maxMotion: float = None,
        minForce: float = None,
        maxForce: float = None,
        components: tuple = (),
    ):
        """This method creates a connector lock behavior option for a ConnectorSection.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                import connectorBehavior
                connectorBehavior.ConnectorLock
                import odbConnectorBehavior
                odbConnectorBehavior.ConnectorLock

        Parameters
        ----------
        lockingComponent
            The SymbolicConstant ALL or an Int specifying the motion components that are locked. If
            an Int is specified, only that motion component is locked when the locking criteria are
            satisfied. If **lockingComponent** = ALL, all motion components are locked. The default
            value is ALL.
        minMotion
            None or a Float specifying the lower bound for the connector's relative position for all
            specified components, or no lower bound. The default value is None.
        maxMotion
            None or a Float specifying the upper bound for the connector's relative position for all
            specified components, or no upper bound. The default value is None.
        minForce
            None or a Float specifying the lower bound of the force or moment in the directions of
            the specified components at which locking occurs, or no lower bound. The default value
            is None.
        maxForce
            None or a Float specifying the upper bound of the force or moment in the directions of
            the specified components at which locking occurs, or no upper bound. The default value
            is None.
        components
            A sequence of Ints specifying the components of relative motion for which the behavior
            is defined. Possible values are 1 ≤≤ **components** ≤≤ 6. Only available components can be
            specified. The default value is an empty sequence.

        Returns
        -------
        ConnectorLock
            A :py:class:`~abaqus.Connector.ConnectorLock.ConnectorLock` object.

        Raises
        ------
        ValueError and TextError
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ConnectorLock object.

        Raises
        ------
        ValueError
        """
        ...
